==> dcd-0.4.8.tar.bz2: dcd-0.4.8/src/misc.h <==
/* $Id: misc.h,v 1.50 2004/10/24 10:37:24 rav Exp $ */

/* Intro {{{
 * ---------------------------------------------------------------- 
 *  DConnect Daemon
 * 
 *      #(@) Copyright (c) 2002, DConnect development team
 *      #(@) Homepage: http://www.dc.ds.pg.gda.pl/
 *
 *  This  program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY  or  FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You  should  have  received a copy  of  the GNU General Public
 *  License  along  with  this  program;  if  not,  write  to  the
 *  Free  Software  Foundation,  Inc.,  675  Mass  Ave,  Cambridge,
 *  MA 02139, USA. 
 *
 * ---------------------------------------------------------------- 
 * }}} */

#if !defined( __vXhz__MISC_H__INCLUDED__ )
#define __vXhz__MISC_H__INCLUDED__

// various defines:
extern int NUSERS;			/* current number of users */
extern time_t starttime;	/* start time in sec */

// lock generator: 'salt Pk=privkey'
void lockgen( char *lock, char *pk );

// feed a random numbers generator
void randomize( void );

// convert user's nick to table index
int nick2id( char *nick );

// usr2id() - convert user's data pointer to table index
int usr2id( struct userrec *usr );

// check if a given nick is a valid one
char validnick(fd_set *fdset, struct userrec *usr, char *nick );

// check for a valid $Key sequence
char validkey( char *key );

// fill user's record with data received in $MyINFO
char fill_info( struct userrec *usr, char *info );

// check clients' idle time
void check_timeout( fd_set *fdset,struct userrec *usr );

#ifdef __Buggy_RH
// workaround for broken libwrap from RH
int yp_get_default_domain(char **ptr);
#endif

// check if remote host is not allowed to connect
char denied( int sock );

// parse options
void parse_options( struct config *conf, int argc, char *argv[] );

// from openssh
char *get_progname( char *argv0 );

// allocate a sufficiently large string and print into it - simplified version
char *my_vsprintf( const char *fmt, va_list ap );

// debugging / logging
void debug( char level, const char *fmt, ...);

// compose direct path to file
void make_path( char *dir, char **file );

// compose direct paths to files for further use
void make_paths( struct config *conf );

// return string representing daemon's uptime
char *uptime( time_t starttime );

/* controlled realloc */
void *my_realloc( void *ptr,size_t size );

/* controlled malloc */
void *my_malloc( size_t size );

/* a semaphored inet_ntoa */
char *my_inet_ntoa( struct in_addr addr );

/* memleak controlled strdup()*/
void my_duplicate(char *str, char **duplicate);
//void my_duplicate1(char *str, char **duplicate,char *plik, int linia);
//#define my_duplicate(x,y) my_duplicate1(x,y,__FILE__,__LINE__)

/* controlled free */
void my_free1( void *ptr );
#define my_free(x) my_free1(&(x))

/* toggle configuration flag */
inline void toggle_flag( fd_set *fdset,struct config *conf,struct userrec *usr,unsigned char flag );

#ifdef INCLUDED_DAEMON
/* fall into background */
int daemon(int nochdir,int noclose);
#endif /* INCLUDED_DAEMON */

#endif /* __vXhz__MISC_H__INCLUDED__ */

/* VIM Settings {{{
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * soft-stop-width: 4
 * c indent on
 * End:
 * vim600: sw=4 ts=4 sts=4 cindent fdm=marker
 * vim<600: sw=4 ts=4
 * }}} */

==> dcd-0.5.9.tar.bz2: dcd-0.5.9/src/misc.h <==
/* $Id: misc.h,v 1.54 2005/11/16 13:48:41 rav Exp $ */

/* Intro {{{
 * ----------------------------------------------------------------
 * DConnect Daemon
 *
 *	 #(@) Copyright (c) 2002, DConnect development team
 *	 #(@) Homepage: http://www.dc.ds.pg.gda.pl/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
 * MA 02139, USA.
 *
 * ----------------------------------------------------------------
 * }}} */

#if !defined( __vXhz__MISC_H__INCLUDED__ )
#define __vXhz__MISC_H__INCLUDED__

// various defines:
extern int NUSERS;			/* current number of users */
extern time_t starttime;	/* start time in sec */

// lock generator: 'salt Pk=privkey'
void lockgen( char *lock, char *pk );

// feed a random numbers generator
void randomize( void );

// convert user's nick to table index
int nick2id( char *nick );

// usr2id() - convert user's data pointer to table index
int usr2id( userrec_t *usr );

// check if a given nick is a valid one
char validnick(userrec_t *usr, char *nick );

// check for a valid $Key sequence
char validkey( char *key );

// fill user's record with data received in $MyINFO
int fill_myinfo( userrec_t *usr, myinfo_t *myinfo, char *info );
int compare_myinfo( myinfo_t *myinfo0, myinfo_t *myinfo1 );
void free_myinfo( myinfo_t *myinfo );
void move_myinfo( myinfo_t *from, myinfo_t *to);

// check clients' idle time
void check_timeout(userrec_t *usr );

#ifdef __Buggy_RH
// workaround for broken libwrap from RH
int yp_get_default_domain(char **ptr);
#endif

// check if remote host is not allowed to connect
char denied( int sock );

// parse options
void parse_options( config_t *conf, int argc, char *argv[] );

// from openssh
char *get_progname( char *argv0 );

// allocate a sufficiently large string and print into it - simplified version
char *my_vsprintf( const char *fmt, va_list ap );

// debugging / logging
void debug( char level, const char *fmt, ...);

// compose direct path to file
void make_path( char *dir, char **file );

// compose direct paths to files for further use
void make_paths( config_t *conf );

// return string representing daemon's uptime
void uptime( time_t starttime, char *str );

/* controlled realloc */
void *my_realloc( void *ptr,size_t size );

/* controlled malloc */
void *my_malloc( size_t size );

/* a semaphored inet_ntoa */
char *my_inet_ntoa( struct in_addr addr );

/* memleak controlled strdup()*/
void my_duplicate(char *str, char **duplicate);
//void my_duplicate1(char *str, char **duplicate,char *plik, int linia);
//#define my_duplicate(x,y) my_duplicate1(x,y,__FILE__,__LINE__)

/* controlled free */
void my_free1( void *ptr );
#define my_free(x) my_free1(&(x))

/* toggle configuration flag */
inline void toggle_flag( config_t *conf,userrec_t *usr,unsigned char flag );

#ifdef INCLUDED_DAEMON
/* fall into background */
int daemon(int nochdir,int noclose);
#endif /* INCLUDED_DAEMON */

#endif /* __vXhz__MISC_H__INCLUDED__ */

/* VIM Settings {{{
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * soft-stop-width: 4
 * c indent on
 * End:
 * vim600: sw=4 ts=4 sts=4 cindent fdm=marker
 * vim<600: sw=4 ts=4
 * }}} */
